@@ -9,30 +9,30 @@
 #' @param normalize Normalize the table by row total, column totals, or overall total
 #' @param tabfilt Expression used to filter the table (e.g., "Total > 10000")
 #' @param tabsort Expression used to sort the table (e.g., "desc(Total)")
+#' @param tabslice Expression used to filter table (e.g., "1:5")
 #' @param nr Number of rows to display
 #' @param data_filter Expression used to filter the dataset before creating the table (e.g., "price > 10000")
+#' @param arr Expression to arrange (sort) the data on (e.g., "color, desc(price)")
+#' @param rows Rows to select from the specified dataset
 #' @param envir Environment to extract data from
 #'
 #' @examples
 #' pivotr(diamonds, cvars = "cut") %>% str()
 #' pivotr(diamonds, cvars = "cut")$tab
-#' pivotr(diamonds, cvars = c("cut","clarity","color"))$tab
+#' pivotr(diamonds, cvars = c("cut", "clarity", "color"))$tab
 #' pivotr(diamonds, cvars = "cut:clarity", nvar = "price")$tab
 #' pivotr(diamonds, cvars = "cut", nvar = "price")$tab
 #' pivotr(diamonds, cvars = "cut", normalize = "total")$tab
 #'
 #' @export
-pivotr <- function(
-  dataset, cvars = "", nvar = "None", fun = "mean",
-  normalize = "None", tabfilt = "", tabsort = "", nr = Inf,
-  data_filter = "", envir = parent.frame()
-) {
-
+pivotr <- function(dataset, cvars = "", nvar = "None", fun = "mean",
+                   normalize = "None", tabfilt = "", tabsort = "", tabslice = "",
+                   nr = Inf, data_filter = "", arr = "", rows = NULL, envir = parent.frame()) {
   vars <- if (nvar == "None") cvars else c(cvars, nvar)
   fill <- if (nvar == "None") 0L else NA
 
   df_name <- if (is_string(dataset)) dataset else deparse(substitute(dataset))
-  dataset <- get_data(dataset, vars, filt = data_filter, na.rm = FALSE, envir = envir)
+  dataset <- get_data(dataset, vars, filt = data_filter, arr = arr, rows = rows, na.rm = FALSE, envir = envir)
 
   ## in case : was used for cvars
   cvars <- base::setdiff(colnames(dataset), nvar)
@@ -75,7 +75,7 @@ pivotr <- function(
   }
   sfun <- function(x, nvar, cvars = "", fun = fun) {
     if (nvar == "n_obs") {
-      if (radiant.data::is_empty(cvars)) {
+      if (is.empty(cvars)) {
         count(x) %>% dplyr::rename("n_obs" = "n")
       } else {
         count(select_at(x, .vars = cvars)) %>% dplyr::rename("n_obs" = "n")
@@ -94,7 +94,9 @@ pivotr <- function(
     sfun(nvar, cvars, fun)
 
   ## total
-  total <- dataset %>% sel(nvar) %>% sfun(nvar, fun = fun)
+  total <- dataset %>%
+    sel(nvar) %>%
+    sfun(nvar, fun = fun)
 
   ## row and colum totals
   if (length(cvars) == 1) {
@@ -103,8 +105,8 @@ pivotr <- function(
         mutate_at(ungroup(tab), .vars = cvars, .funs = as.character),
         bind_cols(
           data.frame("Total", stringsAsFactors = FALSE) %>%
-          setNames(cvars), total %>%
-          set_colnames(nvar)
+            setNames(cvars), total %>%
+            set_colnames(nvar)
         )
       )
   } else {
@@ -124,7 +126,7 @@ pivotr <- function(
       set_colnames("Total")
 
     ## creating cross tab
-    tab <- spread(tab, !! cvars[1], !! nvar, fill = fill) %>%
+    tab <- spread(tab, !!cvars[1], !!nvar, fill = fill) %>%
       ungroup() %>%
       mutate_at(.vars = cvars[-1], .funs = as.character)
 
@@ -146,18 +148,19 @@ pivotr <- function(
   ind <- ifelse(length(cvars) > 1, -1, 1)
   levs <- lapply(select_at(dataset, .vars = cvars[ind]), levels)
 
-  for (i in cvars[ind])
+  for (i in cvars[ind]) {
     tab[[i]] %<>% factor(levels = unique(c(levs[[i]], "Total")))
+  }
 
   ## frequency table for chi-square test
   tab_freq <- tab
 
   isNum <- if (length(cvars) == 1) -1 else -c(1:(length(cvars) - 1))
   if (normalize == "total") {
-    tab[, isNum] %<>% {. / total[[1]]}
+    tab[, isNum] %<>% (function(x) x / total[[1]])
   } else if (normalize == "row") {
     if (!is.null(tab[["Total"]])) {
-      tab[, isNum] %<>% {. / .[["Total"]]}
+      tab[, isNum] %<>% (function(x) x / x[["Total"]])
     }
   } else if (length(cvars) > 1 && normalize == "column") {
     tab[, isNum] %<>% apply(2, function(.) . / .[which(tab[, 1] == "Total")])
@@ -172,7 +175,7 @@ pivotr <- function(
   colnames(tab)[cni] <- fix_names(cn[cni])
 
   ## filtering the table if desired
-  if (!radiant.data::is_empty(tabfilt)) {
+  if (!is.empty(tabfilt)) {
     tab <- tab[-nrow(tab), ] %>%
       filter_data(tabfilt, drop = FALSE) %>%
       bind_rows(tab[nrow(tab), ]) %>%
@@ -180,9 +183,9 @@ pivotr <- function(
   }
 
   ## sorting the table if desired
-  if (!radiant.data::is_empty(tabsort, "")) {
+  if (!is.empty(tabsort, "")) {
     tabsort <- gsub(",", ";", tabsort)
-    tab[-nrow(tab), ] %<>% arrange(!!! rlang::parse_exprs(tabsort))
+    tab[-nrow(tab), ] %<>% arrange(!!!rlang::parse_exprs(tabsort))
 
     ## order factors as set in the sorted table
     tc <- if (length(cvars) == 1) cvars else cvars[-1] ## don't change top cv
@@ -191,6 +194,14 @@ pivotr <- function(
     }
   }
 
+  ## slicing the table if desired
+  if (!is.empty(tabslice)) {
+    tab <- tab %>%
+      slice_data(tabslice) %>%
+      bind_rows(tab[nrow(tab), , drop = FALSE]) %>%
+      droplevels()
+  }
+
   tab <- as.data.frame(tab, stringsAsFactors = FALSE)
   attr(tab, "radiant_nrow") <- nrow_tab
   if (!isTRUE(is.infinite(nr))) {
@@ -223,23 +234,29 @@ pivotr <- function(
 #' @seealso \code{\link{pivotr}} to create the pivot-table using dplyr
 #'
 #' @export
-summary.pivotr <- function(
-  object, perc = FALSE, dec = 3,
-  chi2 = FALSE, shiny = FALSE, ...
-) {
-
+summary.pivotr <- function(object, perc = FALSE, dec = 3,
+                           chi2 = FALSE, shiny = FALSE, ...) {
   if (!shiny) {
     cat("Pivot table\n")
     cat("Data        :", object$df_name, "\n")
-    if (!radiant.data::is_empty(object$data_filter)) {
+    if (!is.empty(object$data_filter)) {
       cat("Filter      :", gsub("\\n", "", object$data_filter), "\n")
     }
-    if (!radiant.data::is_empty(object$tabfilt)) {
+    if (!is.empty(object$arr)) {
+      cat("Arrange     :", gsub("\\n", "", object$arr), "\n")
+    }
+    if (!is.empty(object$rows)) {
+      cat("Slice       :", gsub("\\n", "", object$rows), "\n")
+    }
+    if (!is.empty(object$tabfilt)) {
       cat("Table filter:", object$tabfilt, "\n")
     }
-    if (!radiant.data::is_empty(object$tabsort[1])) {
+    if (!is.empty(object$tabsort[1])) {
       cat("Table sorted:", paste0(object$tabsort, collapse = ", "), "\n")
     }
+    if (!is.empty(object$tabslice)) {
+      cat("Table slice :", object$tabslice, "\n")
+    }
     nr <- attr(object$tab, "radiant_nrow")
     if (!isTRUE(is.infinite(nr)) && !isTRUE(is.infinite(object$nr)) && object$nr < nr) {
       cat(paste0("Rows shown  : ", object$nr, " (out of ", nr, ")\n"))
@@ -263,7 +280,9 @@ summary.pivotr <- function(
         filter(.[[1]] != "Total") %>%
         select(-which(names(.) %in% c(object$cvars, "Total"))) %>%
         mutate_all(~ ifelse(is.na(.), 0, .)) %>%
-        {sshhr(chisq.test(., correct = FALSE))}
+        {
+          sshhr(chisq.test(., correct = FALSE))
+        }
 
       res <- tidy(cst)
       if (dec < 4 && res$p.value < .001) {
@@ -298,13 +317,14 @@ summary.pivotr <- function(
 #' @param searchCols Column search and filter
 #' @param order Column sorting
 #' @param pageLength Page length
+#' @param caption Table caption
 #' @param ... further arguments passed to or from other methods
 #'
 #' @examples
 #' \dontrun{
 #' pivotr(diamonds, cvars = "cut") %>% dtab()
-#' pivotr(diamonds, cvars = c("cut","clarity")) %>% dtab(format = "color_bar")
-#' pivotr(diamonds, cvars = c("cut","clarity"), normalize = "total") %>%
+#' pivotr(diamonds, cvars = c("cut", "clarity")) %>% dtab(format = "color_bar")
+#' pivotr(diamonds, cvars = c("cut", "clarity"), normalize = "total") %>%
 #'   dtab(format = "color_bar", perc = TRUE)
 #' }
 #'
@@ -312,24 +332,21 @@ summary.pivotr <- function(
 #' @seealso \code{\link{summary.pivotr}} to print the table
 #'
 #' @export
-dtab.pivotr <- function(
-  object, format = "none", perc = FALSE, dec = 3,
-  searchCols = NULL, order = NULL, pageLength = NULL,
-  ...
-) {
-
-  style = if (exists("bslib_current_version") && "4" %in% bslib_current_version()) "bootstrap4" else "bootstrap"
+dtab.pivotr <- function(object, format = "none", perc = FALSE, dec = 3,
+                        searchCols = NULL, order = NULL, pageLength = NULL,
+                        caption = NULL, ...) {
+  style <- if (exists("bslib_current_version") && "4" %in% bslib_current_version()) "bootstrap4" else "bootstrap"
   tab <- object$tab
   cvar <- object$cvars[1]
   cvars <- object$cvars %>%
-    {if (length(.) > 1) .[-1] else .}
+    (function(x) if (length(x) > 1) x[-1] else x)
   cn <- colnames(tab) %>%
-    {.[-which(cvars %in% .)]}
+    (function(x) x[-which(cvars %in% x)])
 
   ## for rounding
   isDbl <- sapply(tab, is_double)
   isInt <- sapply(tab, is.integer)
-  dec <- ifelse(radiant.data::is_empty(dec) || dec < 0, 3, round(dec, 0))
+  dec <- ifelse(is.empty(dec) || dec < 0, 3, round(dec, 0))
 
   ## column names without total
   cn_nt <- if ("Total" %in% cn) cn[-which(cn == "Total")] else cn
@@ -354,6 +371,12 @@ dtab.pivotr <- function(
     ))
   }
 
+  if (!is.empty(caption)) {
+    ## from https://github.com/rstudio/DT/issues/630#issuecomment-461191378
+    caption <- shiny::tags$caption(style = "caption-side: bottom; text-align: left; font-size:100%;", caption)
+  }
+
+
   ## remove row with column totals
   ## should perhaps be part of pivotr but convenient for now in tfoot
   ## and for external calls to pivotr
@@ -364,6 +387,7 @@ dtab.pivotr <- function(
   dt_tab <- DT::datatable(
     tab,
     container = sketch,
+    caption = caption,
     selection = "none",
     rownames = FALSE,
     filter = fbox,
@@ -389,7 +413,7 @@ dtab.pivotr <- function(
     callback = DT::JS('$(window).on("unload", function() { table.state.clear(); })')
   ) %>%
     DT::formatStyle(., cvars, color = "white", backgroundColor = "grey") %>%
-    {if ("Total" %in% cn) DT::formatStyle(., "Total", fontWeight = "bold") else .}
+    (function(x) if ("Total" %in% cn) DT::formatStyle(x, "Total", fontWeight = "bold") else x)
 
   ## heat map with red or color_bar
   if (format == "color_bar") {
@@ -406,7 +430,7 @@ dtab.pivotr <- function(
     brks <- quantile(tab[, cn_nt], probs = seq(.05, .95, .05), na.rm = TRUE) %>% round(5)
     clrs <- seq(255, 40, length.out = length(brks) + 1) %>%
       round(0) %>%
-      {paste0("rgb(255,", ., ",", ., ")")}
+      (function(x) paste0("rgb(255,", x, ",", x, ")"))
 
     dt_tab <- DT::formatStyle(dt_tab, cn_nt, backgroundColor = DT::styleInterval(brks, clrs))
   }
@@ -415,8 +439,9 @@ dtab.pivotr <- function(
     ## show percentages
     dt_tab <- DT::formatPercentage(dt_tab, cn, dec)
   } else {
-    if (sum(isDbl) > 0)
+    if (sum(isDbl) > 0) {
       dt_tab <- DT::formatRound(dt_tab, names(isDbl)[isDbl], dec)
+    }
     if (sum(isInt) > 0) {
       dt_tab <- DT::formatRound(dt_tab, names(isInt)[isInt], 0)
     }
@@ -451,20 +476,18 @@ dtab.pivotr <- function(
 #' @seealso \code{\link{pivotr}} to generate summaries
 #' @seealso \code{\link{summary.pivotr}} to show summaries
 #'
+#' @importFrom rlang .data
+#'
 #' @export
-plot.pivotr <- function(
-  x, type = "dodge", perc = FALSE, flip = FALSE,
-  fillcol = "blue", opacity = 0.5, ...
-) {
-
+plot.pivotr <- function(x, type = "dodge", perc = FALSE, flip = FALSE,
+                        fillcol = "blue", opacity = 0.5, ...) {
   cvars <- x$cvars
   nvar <- x$nvar
-  tab <- x$tab %>% {
-    filter(., .[[1]] != "Total")
-  }
+  tab <- x$tab %>%
+    (function(x) filter(x, x[[1]] != "Total"))
 
   if (length(cvars) == 1) {
-    p <- ggplot(na.omit(tab), aes_string(x = cvars, y = nvar)) +
+    p <- ggplot(na.omit(tab), aes(x = .data[[cvars]], y = .data[[nvar]])) +
       geom_bar(stat = "identity", position = "dodge", alpha = opacity, fill = fillcol)
   } else if (length(cvars) == 2) {
     ctot <- which(colnames(tab) == "Total")
@@ -475,10 +498,10 @@ plot.pivotr <- function(
       set_names(cvars[1])
 
     p <- tab %>%
-      gather(!! cvars[1], !! nvar, !! base::setdiff(colnames(.), cvars[2])) %>%
+      gather(!!cvars[1], !!nvar, !!base::setdiff(colnames(.), cvars[2])) %>%
       na.omit() %>%
-      mutate(!!! dots) %>%
-      ggplot(aes_string(x = cvars[1], y = nvar, fill = cvars[2])) +
+      mutate(!!!dots) %>%
+      ggplot(aes(x = .data[[cvars[1]]], y = .data[[nvar]], fill = .data[[cvars[2]]])) +
       geom_bar(stat = "identity", position = type, alpha = opacity)
   } else if (length(cvars) == 3) {
     ctot <- which(colnames(tab) == "Total")
@@ -489,10 +512,10 @@ plot.pivotr <- function(
       set_names(cvars[1])
 
     p <- tab %>%
-      gather(!! cvars[1], !! nvar, !! base::setdiff(colnames(.), cvars[2:3])) %>%
+      gather(!!cvars[1], !!nvar, !!base::setdiff(colnames(.), cvars[2:3])) %>%
       na.omit() %>%
-      mutate(!!! dots) %>%
-      ggplot(aes_string(x = cvars[1], y = nvar, fill = cvars[2])) +
+      mutate(!!!dots) %>%
+      ggplot(aes(x = .data[[cvars[1]]], y = .data[[nvar]], fill = .data[[cvars[2]]])) +
       geom_bar(stat = "identity", position = type, alpha = opacity) +
       facet_grid(paste(cvars[3], "~ ."))
   } else {
@@ -504,7 +527,7 @@ plot.pivotr <- function(
   if (perc) p <- p + scale_y_continuous(labels = scales::percent)
 
   if (isTRUE(nvar == "n_obs")) {
-    if (!radiant.data::is_empty(x$normalize, "None")) {
+    if (!is.empty(x$normalize, "None")) {
       p <- p + labs(y = ifelse(perc, "Percentage", "Proportion"))
     }
   } else {
@@ -540,4 +563,4 @@ store.pivotr <- function(dataset, object, name, ...) {
       call. = FALSE
     )
   }
-}
+}
\ No newline at end of file
