@@ -17,8 +17,9 @@ dtab <- function(object, ...) UseMethod("dtab", object)
 #' @param object Data.frame to display
 #' @param vars Variables to show (default is all)
 #' @param filt Filter to apply to the specified dataset. For example "price > 10000" if dataset is "diamonds" (default is "")
+#' @param arr Expression to arrange (sort) the data on (e.g., "color, desc(price)")
 #' @param rows Select rows in the specified dataset. For example "1:10" for the first 10 rows or "n()-10:n()" for the last 10 rows (default is NULL)
-#' @param nr Number of rows of data to include in the table
+#' @param nr Number of rows of data to include in the table. This function will be mainly used in reports so it is best to keep this number small
 #' @param na.rm Remove rows with missing values (default is FALSE)
 #' @param dec Number of decimal places to show. Default is no rounding (NULL)
 #' @param perc Vector of column names to be displayed as a percentage
@@ -38,24 +39,22 @@ dtab <- function(object, ...) UseMethod("dtab", object)
 #' }
 #'
 #' @export
-dtab.data.frame <- function(
-  object, vars = "", filt = "", rows = NULL,
-  nr = NULL, na.rm = FALSE, dec = 3, perc = "",
-  filter = "top", pageLength = 10, dom = "",
-  style = "bootstrap4", rownames = FALSE,
-  caption = NULL,
-  envir = parent.frame(), ...
-) {
-
-  dat <- get_data(object, vars, filt = filt, rows = rows, na.rm = na.rm, envir = envir)
-  if (!radiant.data::is_empty(nr) && nr < nrow(dat)) {
+dtab.data.frame <- function(object, vars = "", filt = "", arr = "", rows = NULL,
+                            nr = NULL, na.rm = FALSE, dec = 3, perc = "",
+                            filter = "top", pageLength = 10, dom = "",
+                            style = "bootstrap4", rownames = FALSE,
+                            caption = NULL,
+                            envir = parent.frame(), ...) {
+  ## does this need a data_view_rows argument?
+  dat <- get_data(object, vars, filt = filt, arr = arr, rows = rows, na.rm = na.rm, envir = envir)
+  if (!is.empty(nr) && nr < nrow(dat)) {
     dat <- dat[seq_len(nr), , drop = FALSE]
   }
 
   ## for rounding
   isInt <- sapply(dat, is.integer)
   isDbl <- sapply(dat, is_double)
-  dec <- ifelse(radiant.data::is_empty(dec) || dec < 0, 3, round(dec, 0))
+  dec <- ifelse(is.empty(dec) || dec < 0, 3, round(dec, 0))
 
   ## don't do normal rounding for perc variables
   isInt[intersect(names(isInt), perc)] <- FALSE
@@ -66,13 +65,13 @@ dtab.data.frame <- function(
   dat <- mutate_if(dat, isBigFct, as.character)
 
   ## for display options see https://datatables.net/reference/option/dom
-  if (radiant.data::is_empty(dom)) {
+  if (is.empty(dom)) {
     dom <- if (pageLength == -1 || nrow(dat) < pageLength) "t" else "lftip"
   }
 
-  if (!radiant.data::is_empty(caption)) {
+  if (!is.empty(caption)) {
     ## from https://github.com/rstudio/DT/issues/630#issuecomment-461191378
-    caption <- shiny::tags$caption(style = 'caption-side: top; text-align: left; color:black; font-size:150%;', caption)
+    caption <- shiny::tags$caption(style = "caption-side: bottom; text-align: left; font-size:100%;", caption)
   }
 
   dt_tab <- DT::datatable(
@@ -102,12 +101,15 @@ dtab.data.frame <- function(
   )
 
   ## rounding as needed
-  if (sum(isDbl) > 0)
+  if (sum(isDbl) > 0) {
     dt_tab <- DT::formatRound(dt_tab, colnames(dat)[isDbl], digits = dec)
-  if (sum(isInt) > 0)
+  }
+  if (sum(isInt) > 0) {
     dt_tab <- DT::formatRound(dt_tab, colnames(dat)[isInt], digits = 0)
-  if (!radiant.data::is_empty(perc))
+  }
+  if (!is.empty(perc)) {
     dt_tab <- DT::formatPercentage(dt_tab, perc, digits = dec)
+  }
 
   ## see https://github.com/yihui/knitr/issues/1198
   dt_tab$dependencies <- c(
@@ -132,24 +134,85 @@ filter_data <- function(dataset, filt = "", drop = TRUE) {
   if (grepl("([^=!<>])=([^=])", filt)) {
     message("Invalid filter: Never use = in a filter. Use == instead (e.g., year == 2014). Update or remove the expression")
   } else {
-    seldat <- try(
-      ## use %>% so . will be available to represent the available data in filters
-      dataset %>% filter(!! rlang::parse_expr(fix_smart(filt))),
-      silent = TRUE
-    )
-    if (inherits(seldat, "try-error")) {
-      message(paste0("Invalid filter: \"", attr(seldat, "condition")$message, "\". Update or remove the expression"))
+    filter_dat <- try(dataset %>% filter(!!rlang::parse_expr(filt)), silent = TRUE)
+    if (inherits(filter_dat, "try-error")) {
+      message(paste0("Invalid filter: \"", attr(filter_dat, "condition")$message, "\". Update or remove the expression"))
     } else {
       if (drop) {
-        return(droplevels(seldat))
+        return(droplevels(filter_dat))
       } else {
-        return(seldat)
+        return(filter_dat)
       }
     }
   }
   dataset
 }
 
+#' Generate arrange commands from user input
+#' @details Form arrange command from user input
+#' @param expr Expression to use arrange rows from the specified dataset
+#' @param dataset String with dataset name
+#' @return Arrange command
+#' @importFrom glue glue
+#' @export
+make_arrange_cmd <- function(expr, dataset = "") {
+  expr %>%
+    strsplit(., split = "(\\s*&\\s*|\\s*,\\s*|\\s+)") %>%
+    unlist() %>%
+    .[!. == ""] %>%
+    paste0(collapse = ", ") %>%
+    (function(x) ifelse(is.empty(dataset), glue("arrange({x})"), glue("arrange({dataset}, {x})")))
+}
+
+# dataset <- mtcars
+# expr <- "desc(mpg)     &    vs , am"
+# make_arrange_cmd("dataset", expr)
+
+#' Arrange data with user-specified expression
+#' @details Arrange data, likely in combination with slicing
+#' @param dataset Data frame to arrange
+#' @param expr Expression to use arrange rows from the specified dataset
+#' @return Arranged data frame
+#' @export
+arrange_data <- function(dataset, expr = NULL) {
+  if (!is.empty(expr)) {
+    arrange_cmd <- make_arrange_cmd(expr, "dataset")
+    arrange_dat <- try(eval(parse(text = arrange_cmd)), silent = TRUE)
+    if (inherits(arrange_dat, "try-error")) {
+      message(paste0("Invalid arrange expression: \"", attr(arrange_dat, "condition")$message, "\". Update or remove the expression"))
+    } else {
+      return(arrange_dat)
+    }
+  }
+
+  dataset
+}
+
+#' Slice data with user-specified expression
+#' @details Select only a slice of the data to work with
+#' @param dataset Data frame to slice
+#' @param expr Expression to use select rows from the specified dataset
+#' @param drop Drop unused factor levels after filtering (default is TRUE)
+#' @return Sliced data frame
+#' @export
+slice_data <- function(dataset, expr = NULL, drop = TRUE) {
+  if (is.numeric(expr)) {
+    slice_dat <- try(dataset %>% slice(expr), silent = TRUE)
+  } else {
+    slice_dat <- try(dataset %>% slice(!!rlang::parse_expr(expr)), silent = TRUE)
+  }
+  if (inherits(slice_dat, "try-error")) {
+    message(paste0("Invalid slice: \"", attr(slice_dat, "condition")$message, "\". Update or remove the expression"))
+  } else {
+    if (drop) {
+      return(droplevels(slice_dat))
+    } else {
+      return(slice_dat)
+    }
+  }
+  dataset
+}
+
 #' Search for a pattern in all columns of a data.frame
 #'
 #' @param dataset Data.frame to search
@@ -176,6 +239,7 @@ search_data <- function(dataset, pattern, ignore.case = TRUE, fixed = FALSE) {
 #' @param dataset Data.frame or name of the dataframe to view
 #' @param vars Variables to show (default is all)
 #' @param filt Filter to apply to the specified dataset
+#' @param arr Expression to arrange (sort) data
 #' @param rows Select rows in the specified dataset
 #' @param na.rm Remove rows with missing values (default is FALSE)
 #' @param dec Number of decimals to show
@@ -189,14 +253,12 @@ search_data <- function(dataset, pattern, ignore.case = TRUE, fixed = FALSE) {
 #' }
 #'
 #' @export
-view_data <- function(
-  dataset, vars = "", filt = "",
-  rows = NULL, na.rm = FALSE, dec = 3,
-  envir = parent.frame()
-) {
+view_data <- function(dataset, vars = "", filt = "",
+                      arr = "", rows = NULL, na.rm = FALSE, dec = 3,
+                      envir = parent.frame()) {
 
   ## based on https://rstudio.github.io/DT/server.html
-  dat <- get_data(dataset, vars, filt = filt, rows = rows, na.rm = na.rm, envir = envir)
+  dat <- get_data(dataset, vars, filt = filt, arr = arr, rows = rows, na.rm = na.rm, envir = envir)
   title <- if (is_string(dataset)) paste0("DT:", dataset) else "DT"
   fbox <- if (nrow(dat) > 5e6) "none" else list(position = "top")
 
@@ -207,7 +269,7 @@ view_data <- function(
   ## for rounding
   isDbl <- sapply(dat, is_double)
   isInt <- sapply(dat, is.integer)
-  dec <- ifelse(radiant.data::is_empty(dec) || dec < 0, 3, round(dec, 0))
+  dec <- ifelse(is.empty(dec) || dec < 0, 3, round(dec, 0))
 
   shinyApp(
     ui = fluidPage(
@@ -243,12 +305,13 @@ view_data <- function(
           lengthMenu = list(c(5, 10, 25, 50, -1), c("5", "10", "25", "50", "All"))
         )
       ) %>%
-        {if (sum(isDbl) > 0) DT::formatRound(., names(isDbl)[isDbl], dec) else .} %>%
-        {if (sum(isInt) > 0) DT::formatRound(., names(isInt)[isInt], 0) else .}
+        (function(x) if (sum(isDbl) > 0) DT::formatRound(x, names(isDbl)[isDbl], dec) else x) %>%
+        (function(x) if (sum(isInt) > 0) DT::formatRound(x, names(isInt)[isInt], 0) else x)
+
       output$tbl <- DT::renderDataTable(widget)
       observeEvent(input$stop, {
         stopApp(cat("Stopped view_data"))
       })
     }
   )
-}
+}
\ No newline at end of file
