@@ -23,7 +23,7 @@ file_upload_button <- function(inputId, label = "", multiple = FALSE,
       accept <- ""
     }
 
-    if (!radiant.data::is_empty(label)) {
+    if (!is.empty(label)) {
       label <- paste0("</br><label>", label, "</label></br>")
     }
 
@@ -66,7 +66,7 @@ rstudio_context <- function(type = "rmd") {
   path <- rse$path
   ext <- tools::file_ext(path)
 
-  if (radiant.data::is_empty(path) || !file.exists(path) || tolower(ext) != type) {
+  if (is.empty(path) || !file.exists(path) || tolower(ext) != type) {
     ## path will be empty of new file hasn't been save yet
     list(path = "", rpath = "", base = "", base_name = "", ext = "", content = "")
   } else {
@@ -74,7 +74,7 @@ rstudio_context <- function(type = "rmd") {
     pdir <- getOption("radiant.project_dir", default = radiant.data::find_home())
 
     sel <- rse$selection[[1]][["text"]]
-    if (radiant.data::is_empty(sel)) {
+    if (is.empty(sel)) {
       content <- paste0(rse$content, collapse = "\n")
     } else {
       content <- paste0(sel, collapse = "\n")
@@ -83,7 +83,7 @@ rstudio_context <- function(type = "rmd") {
     base <- basename(path)
     base_name <- sub(paste0(".", ext), "", base)
 
-    rpath <- if (radiant.data::is_empty(pdir)) {
+    rpath <- if (is.empty(pdir)) {
       path
     } else {
       sub(paste0(pdir, "/"), "", path)
@@ -382,7 +382,7 @@ knit_it <- function(report, type = "rmd") {
   pdir <- getOption("radiant.project_dir", default = ldir)
 
   tdir <- tempdir()
-  owd <- ifelse(radiant.data::is_empty(pdir), setwd(tdir), setwd(pdir))
+  owd <- ifelse(is.empty(pdir), setwd(tdir), setwd(pdir))
   on.exit(setwd(owd))
 
   ## sizing issue with ggplotly and knitr
@@ -444,7 +444,7 @@ report_name <- function(type = "rmd", out = "report", full.name = FALSE) {
     fn <- ""
   }
 
-  if (radiant.data::is_empty(fn)) {
+  if (is.empty(fn)) {
     fn <- state_name()
     fn <- sans_ext(fn) %>%
       sub("-state", paste0("-", out), .)
@@ -471,7 +471,7 @@ report_save_filename <- function(type = "rmd", full.name = TRUE) {
 
   if (input[[paste0(type, "_generate")]] %in% c("To Rmd", "To R")) {
     cnt <- rstudio_context(type = type)
-    if (!radiant.data::is_empty(cnt$path)) {
+    if (!is.empty(cnt$path)) {
       if (cnt$path != cnt$rpath) {
         r_state[[paste0("radiant_", type, "_name")]] <<- cnt$rpath
       } else {
@@ -512,7 +512,7 @@ report_save_content <- function(file, type = "rmd") {
       pdir <- getOption("radiant.project_dir", default = ldir)
 
       tdir <- tempdir()
-      owd <- ifelse(radiant.data::is_empty(pdir), setwd(tdir), setwd(pdir))
+      owd <- ifelse(is.empty(pdir), setwd(tdir), setwd(pdir))
       on.exit(setwd(owd))
 
       save_type <- input[[paste0(type, "_save_type")]]
@@ -520,7 +520,7 @@ report_save_content <- function(file, type = "rmd") {
 
       zip_info <- getOption("radiant.zip")
       if (save_type %in% c("Rmd + Data (zip)", "R + Data (zip)")) {
-        if (radiant.data::is_empty(zip_info)) {
+        if (is.empty(zip_info)) {
           ## No zip warning
           showModal(
             modalDialog(
@@ -541,7 +541,7 @@ report_save_content <- function(file, type = "rmd") {
 
       if (generate %in% c("To Rmd", "To R")) {
         cnt <- rstudio_context(type)
-        if (radiant.data::is_empty(cnt$path) || !cnt$ext == type) {
+        if (is.empty(cnt$path) || !cnt$ext == type) {
           if (generate == "To Rmd") {
             report <- "#### Radiant is set to use an rmarkdown document in Rstudio ('To Rmd').\n#### Please check that you have an .Rmd file open in Rstudio and that the file has been saved to disk.\n#### If you want to use the editor in Radiant instead, change 'To Rmd' to 'Auto paste' or 'Manual paste'."
           } else {
@@ -681,7 +681,7 @@ update_report <- function(inp_main = "", fun_name = "", inp_out = list("", ""),
   ## determine number of characters for main command for wrapping
   if (missing(wrap)) {
     lng <- nchar(pre_cmd) + nchar(fun_name) + nchar(post_cmd) + 2
-    if (!radiant.data::is_empty(inp_main)) {
+    if (!is.empty(inp_main)) {
       lng <- lng + sum(nchar(inp_main)) +
         sum(nchar(names(inp_main))) +
         length(inp_main) * 5 - 1
@@ -783,7 +783,7 @@ update_report <- function(inp_main = "", fun_name = "", inp_out = list("", ""),
     } else {
       cmd <- paste0("\n```{r}\n", cmd, "\n```\n")
     }
-    if (!is_empty(r_info[["latest_screenshot"]])) {
+    if (!is.empty(r_info[["latest_screenshot"]])) {
       cmd <- paste0(r_info[["latest_screenshot"]], "\n", cmd)
     }
     update_report_fun(cmd, type = "rmd")
@@ -829,7 +829,7 @@ update_report_fun <- function(cmd, type = "rmd", rfiles = FALSE) {
           rstudioapi::insertText(Inf, .)
       })
     } else {
-      if (radiant.data::is_empty(r_state[[editor]])) {
+      if (is.empty(r_state[[editor]])) {
         r_state[[editor]] <<- paste0("## Your report title\n\n", cmd)
       } else {
         r_state[[editor]] <<- paste0(fix_smart(r_state[[editor]]), "\n", cmd)
